scoreboard — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# scoreboard

Keep track of the score, lines total and high score.

class `scoreboard.` `Scoreboard`(screen)

  The scoreboard.

  Parameters: | screen (`Screen`) – The screen on which the scoreboard is displayed.

  `add_lines`(addend)

    Add lines to the lines total and print it.

    Parameters: | addend – The number of lines to add.

  `add_to_score`(addend)

    Add points to the score and print it.

    Parameters: | addend – The number of points to add.

  `print_score_box`()

    Print the score, lines total and hi-score.

  `reinitialise`()

    Reinitialise the scoreboard after a game has ended. The current score becomes the new high score if necessary, the score and lines total are reset to zero, and all three numbers are printed.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »